import json
import sys
from datetime import datetime

from app.card import card


def main():
    __version__ = "1.0.1"
    career_start_date = datetime.strptime("2014-12-11", "%Y-%m-%d")
    career_continue_date = datetime.now().strftime("%Y-%m-%d")
    career_continue_date = datetime.strptime(career_continue_date, "%Y-%m-%d")

    # Get the total number of days of my experience
    tot_days = abs(career_continue_date - career_start_date).days
    num_years = int(tot_days / 365)
    num_weeks = int((tot_days % 365) / 7)
    num_months = int(num_weeks / 4)

    # Get the total work experience
    work_exp = f"{num_years} years and {num_months} months"

    my_data = {
        "attributes": {
            "profile": {
                "current_designation": "Senior software qa engineer (automation)",
                "organization": "Encora Inc.",
                "working_from": "November, 2020 - till date",
                "ex_organization": "Synup | Equifax | Automatad | Srijan",
                "linkedin_profile": "https://www.linkedin.com/in/soumyajit-basu-5a783886/",
                "github_profile": "https://github.com/Corefinder89",
                "bitbucket_profile": "https://bitbucket.org/CodersDen/"
            },
            "education": {
                "highest_degree": "Post graduation (MSc. computer applications)",
                "university": "Symbiosis International University (Deemed)"
            },
            "personal_details": {
                "name": "Soumyajit Basu",
                "also_known_as": "corefinder",
                "email": "soumyajit.basu62@gmail.com",
                "current_location": "Bengaluru, karnataka",
                "zip_code": 560078
            }
        }
    }

    if "--version" in sys.argv[1:]:
        print(__version__)
        exit(0)

    if "--help" in sys.argv[1:]:
        print("To run the module execute pipx run corefinder")
        print("To install the module execute pipx install corefinder")
        exit(0)

    print(card(my_data, work_exp))


if __name__ == '__main__':
    main()



from textwrap import dedent


def card(json_obj, work_ex):
    phrase = "Soumyajit"
    topbar = "-" * len(phrase)
    bottombar = "-" * len(phrase)
    output = dedent(
        f"""
        {topbar}
        <{phrase}>
        {bottombar}
         \                   .,
           \         .      .TR   d'
             \      k,l    .R.b  .t .Je
               \   .P q.   a|.b .f .Z%
                   .b .h  .E` # J: 2`     .         Name:               {json_obj.get("attributes").
                                                                            get("personal_details").get("name")}
              .,.a .E  ,L.M'  ?:b `| ..J9!`.,       Aka:                {json_obj.get("attributes").
                                                                            get("personal_details").get("also_known_as")}
               q,.h.M`   `..,   ..,""` ..2"`
               .M, J8`   `:       `   3;            Designation:        {json_obj.get("attributes").get("profile").
                                                                            get("current_designation")}
           .    Jk              ...,   `^7"90c.     Organization:       {json_obj.get("attributes").get("profile").
                                                                            get("organization")}
            j,  ,!     .7"'`j,.|   .n.   ...        Working from:       {json_obj.get("attributes").get("profile").
                                                                            get("working_from")}
           j, 7'     .r`     4:      L   `...       Experience:         {work_ex}
          ..,m.      J`    ..,|..    J`  7TWi       Ex-professional:    {json_obj.get("attributes").get("profile").
                                                                            get("ex_organization")}
          ..JJ,.:    %    oo      ,. ....,
            .,E      3     7`g.M:    P  41          Linkedin:           {json_obj.get("attributes").get("profile").
                                                                            get("linkedin_profile")}
           JT7"'      O.   .J,;     ``  V"7N.       GitHub:             {json_obj.get("attributes").get("profile").
                                                                            get("github_profile")}
           G.           ""Q+  .Zu.,!`      Z`       Bitbucket:          {json_obj.get("attributes").get("profile").
                                                                            get("bitbucket_profile")}
           .9.. .         J&..J!       .  ,:        Highest degree:     {json_obj.get("attributes").get("education").
                                                                            get("highest_degree")}
              7"9a                    JM"!          University:         {json_obj.get("attributes").get("education").
                                                                            get("university")}
                 .5J.     ..        ..F`
                    78a..   `    ..2'               Email:              {json_obj.get("attributes").
                                                                            get("personal_details").get("email")}
                        J9Ksaw0"'                   Currently located:  {json_obj.get("attributes").
                                                                            get("personal_details").get("current_location")}
                       .EJ?A...a.                   Zip code:           {json_obj.get("attributes").
                                                                            get("personal_details").get("zip_code")}
                       q...g...gi
                      .m...qa..,y:
                      .HQFNB&...mm
                       ,Z|,m.a.,dp
                    .,?f` ,E?:"^7b
                    `A| . .F^^7'^4,
                     .MMMMMMMMMMMQzna,
                 ...f"A.JdT     J:    Jp,
                  `JNa..........A....af`
                       `^^^^^'`
        """
    )

    return output



from setuptools import setup

with open('README.md') as f:
    long_description = f.read()

setup(
    name="corefinder",
    version="1.1.1",
    author="Soumyajit Basu",
    author_email="soumyajit.basu62@gmail.com",
    description="A module for my digital business card",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/Corefinder89/corefinder",
    packages=['app'],
    include_package_data=True,
    entry_points={"console_scripts": ["corefinder=app.main:main"]},
    zip_safe=False,
    python_requires=">=3.6",
    license="License :: OSI Approved :: MIT License",
    classifiers=["Programming Language :: Python"]
)
